@@ -1,6 +1,5 @@
 #' Organization aggregates: Search for contributions to politicians.
 #'
-#' @import httr
 #' @export
 #' @param method (character) The query string. One of top_ind or top_org.
 #' @param entity_id (character) The transparencydata ID to look up.
@@ -8,8 +7,7 @@
 #' organization, individual or industry.
 #' @param limit (integer) Limit number of records returned.
 #' @template ie
-#' @return A list. Depends on parameters used. Ranges from a single ID returned to basic
-#' information about the the contributions to and from each entity.
+#' @return A data.frame (default), list, or httr response object.
 #'
 #' @examples \dontrun{
 #' # Top industries, By contributions given, in dollars.
@@ -21,20 +19,18 @@
 #' }
 
 ie_industries <- function(method = NULL, entity_id = NULL, cycle = NULL, limit = NULL,
-  page = NULL, per_page = NULL, return='table',
-  key=getOption("SunlightLabsKey", stop("need an API key for Sunlight Labs")), ...)
-{
+  page = NULL, per_page = NULL, as = 'table',
+  key = NULL, ...) {
+
+  key <- check_key(key)
   urlsuffix <- switch(method,
     top_ind = sprintf('industries/top_%s.json', limit),
     top_org = sprintf('industry/%s/orgs.json', entity_id)
   )
 
-  url <- sprintf('http://transparencydata.com/api/1.0/aggregates/%s', urlsuffix)
-  if(method=="top_org") limit <- NULL
-  args <- suncompact(list(apikey = key, cycle = cycle, limit = limit))
+  url <- sprintf('%s/aggregates/%s', ieurl(), urlsuffix)
+  if (method == "top_org") limit <- NULL
+  args <- sc(list(apikey = key, cycle = cycle, limit = limit))
 
-  tt <- GET(url, query=args, ...)
-  stop_for_status(tt)
-  assert_that(tt$headers$`content-type` == 'application/json; charset=utf-8')
-  return_obj(return, tt)
+  return_obj(as, query(url, args, ...))
 }
