@@ -1,10 +1,8 @@
 #' Search OpenStates metadata.
 #'
-#' @import httr
-#' @importFrom plyr compact
 #' @param state One or more two-letter state abbreviations (character)
 #' @param key your SunlightLabs API key; or loads from .Rprofile
-#' @param ... Curl options passed on to httr::GET
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @return A list with metadata for each state.
 #' @export
 #' @examples \dontrun{
@@ -14,26 +12,29 @@
 #' out <- os_statemetasearch(c('tx','nv'))
 #' out$tx
 #' out$nv
-#' 
+#'
 #' library('httr')
 #' os_statemetasearch('tx', config=verbose())
 #' }
-os_statemetasearch <- function(state = NULL,
-    key = getOption("SunlightLabsKey", stop("need an API key for Sunlight Labs")), ...)
-{
-  getdata <- function(x=NULL){
-    url = "http://openstates.org/api/v1/metadata/"
-    if(!is.null(x))
-      url <- paste(url, x, sep= "")
-    url2 <- paste(url, "?apikey=", key, sep= "")
+os_statemetasearch <- function(state = NULL, key = NULL, ...) {
+  key <- check_key(key)
+  getdata <- function(x = NULL){
+    url <- paste0(osurl(), "/metadata/")
+    if (!is.null(x)) {
+      url <- paste(url, x, sep = "")
+    }
+    url2 <- paste(url, "?apikey=", key, sep = "")
     tt <- GET(url2, ...)
     stop_for_status(tt)
     out <- content(tt, as = "text")
-    fromJSON(out)
+    jsonlite::fromJSON(out)
   }
-  if(!is.null(state)){
+
+  if (!is.null(state)) {
     res <- lapply(state, getdata)
     names(res) <- state
     res
-  } else { getdata() }
+  } else {
+    getdata()
+  }
 }
